@@ -1,21 +1,11 @@
 package TestML::Parser::Grammar;
-use base 'Parse::Pegex';
+use base 'Pegex::Grammar';
 use strict;
 use warnings;
 
-our $grammar = +{
-  'ALWAYS' => {
-    '+re' => qr/(?-xism:\G)/
-  },
-  'NO_META_TESTML_ERROR' => {
-    '+rule' => 'ALWAYS'
-  },
-  'SEMI' => {
-    '+re' => qr/(?-xism:\G;)/
-  },
-  'SEMICOLON_ERROR' => {
-    '+rule' => 'ALWAYS'
-  },
+sub grammar_tree {
+    return +{
+  '_FIRST_RULE' => 'document',
   'assertion_call' => {
     '+any' => [
       {
@@ -30,7 +20,7 @@ our $grammar = +{
     ]
   },
   'assertion_call_test' => {
-    '+re' => qr/(?-xism:\G(?:\.(?:[\ \t]|\r?\n|#.*\r?\n)*|(?:[\ \t]|\r?\n|#.*\r?\n)*\.)(?:EQ|OK|HAS)\()/
+    '+re' => qr/(?-xism:\G(?:\.(?:[\ \t]|\r?\n|\#.*\r?\n)*|(?:[\ \t]|\r?\n|\#.*\r?\n)*\.)(?:EQ|OK|HAS)\()/
   },
   'assertion_eq' => {
     '+any' => [
@@ -45,7 +35,7 @@ our $grammar = +{
   'assertion_function_eq' => {
     '+all' => [
       {
-        '+re' => qr/(?-xism:\G(?:\.(?:[\ \t]|\r?\n|#.*\r?\n)*|(?:[\ \t]|\r?\n|#.*\r?\n)*\.)EQ\()/
+        '+re' => qr/(?-xism:\G(?:\.(?:[\ \t]|\r?\n|\#.*\r?\n)*|(?:[\ \t]|\r?\n|\#.*\r?\n)*\.)EQ\()/
       },
       {
         '+rule' => 'test_expression'
@@ -58,7 +48,7 @@ our $grammar = +{
   'assertion_function_has' => {
     '+all' => [
       {
-        '+re' => qr/(?-xism:\G(?:\.(?:[\ \t]|\r?\n|#.*\r?\n)*|(?:[\ \t]|\r?\n|#.*\r?\n)*\.)HAS\()/
+        '+re' => qr/(?-xism:\G(?:\.(?:[\ \t]|\r?\n|\#.*\r?\n)*|(?:[\ \t]|\r?\n|\#.*\r?\n)*\.)HAS\()/
       },
       {
         '+rule' => 'test_expression'
@@ -69,7 +59,7 @@ our $grammar = +{
     ]
   },
   'assertion_function_ok' => {
-    '+re' => qr/(?-xism:\G(?:\.(?:[\ \t]|\r?\n|#.*\r?\n)*|(?:[\ \t]|\r?\n|#.*\r?\n)*\.)OK(?:\((?:[\ \t]|\r?\n|#.*\r?\n)*\))?)/
+    '+re' => qr/(?-xism:\G(?:\.(?:[\ \t]|\r?\n|\#.*\r?\n)*|(?:[\ \t]|\r?\n|\#.*\r?\n)*\.)OK(?:\((?:[\ \t]|\r?\n|\#.*\r?\n)*\))?)/
   },
   'assertion_has' => {
     '+any' => [
@@ -87,7 +77,7 @@ our $grammar = +{
   'assertion_operator_eq' => {
     '+all' => [
       {
-        '+re' => qr/(?-xism:\G(?:[\ \t]|\r?\n|#.*\r?\n)+==(?:[\ \t]|\r?\n|#.*\r?\n)+)/
+        '+re' => qr/(?-xism:\G(?:[\ \t]|\r?\n|\#.*\r?\n)+==(?:[\ \t]|\r?\n|\#.*\r?\n)+)/
       },
       {
         '+rule' => 'test_expression'
@@ -97,7 +87,7 @@ our $grammar = +{
   'assertion_operator_has' => {
     '+all' => [
       {
-        '+re' => qr/(?-xism:\G(?:[\ \t]|\r?\n|#.*\r?\n)+~~(?:[\ \t]|\r?\n|#.*\r?\n)+)/
+        '+re' => qr/(?-xism:\G(?:[\ \t]|\r?\n|\#.*\r?\n)+~~(?:[\ \t]|\r?\n|\#.*\r?\n)+)/
       },
       {
         '+rule' => 'test_expression'
@@ -145,10 +135,10 @@ our $grammar = +{
     ]
   },
   'call_indicator' => {
-    '+re' => qr/(?-xism:\G(?:\.(?:[\ \t]|\r?\n|#.*\r?\n)*|(?:[\ \t]|\r?\n|#.*\r?\n)*\.))/
+    '+re' => qr/(?-xism:\G(?:\.(?:[\ \t]|\r?\n|\#.*\r?\n)*|(?:[\ \t]|\r?\n|\#.*\r?\n)*\.))/
   },
   'comment' => {
-    '+re' => qr/(?-xism:\G#.*\r?\n)/
+    '+re' => qr/(?-xism:\G\#.*\r?\n)/
   },
   'core_transform' => {
     '+re' => qr/(?-xism:\G([A-Z]\w*))/
@@ -233,7 +223,7 @@ our $grammar = +{
   'meta_section' => {
     '+all' => [
       {
-        '+re' => qr/(?-xism:\G(?:#.*\r?\n|[\ \t]*\r?\n)*)/
+        '+re' => qr/(?-xism:\G(?:\#.*\r?\n|[\ \t]*\r?\n)*)/
       },
       {
         '+any' => [
@@ -241,7 +231,7 @@ our $grammar = +{
             '+rule' => 'meta_testml_statement'
           },
           {
-            '+rule' => 'NO_META_TESTML_ERROR'
+            '+error' => 'No TestML meta directive found'
           }
         ]
       },
@@ -262,10 +252,10 @@ our $grammar = +{
     ]
   },
   'meta_statement' => {
-    '+re' => qr/(?-xism:\G%((?:(?:Title|Data|Plan|BlockMarker|PointMarker)|[a-z]\w*)):[\ \t]+((?:(?:'(([^\n\\']|\\'|\\\\)*?)')|(?:"(([^\n\\"]|\\"|\\\\|\\[0nt])*?)")|([^\ \t\n#](?:[^\n#]*[^\ \t\n#])?)))(?:[\ \t]+#.*\r?\n|\r?\n))/
+    '+re' => qr/(?-xism:\G%((?:(?:Title|Data|Plan|BlockMarker|PointMarker)|[a-z]\w*)):[\ \t]+((?:(?:'(([^\n\\']|\\'|\\\\)*?)')|(?:"(([^\n\\"]|\\"|\\\\|\\[0nt])*?)")|([^\ \t\n\#](?:[^\n\#]*[^\ \t\n\#])?)))(?:[\ \t]+\#.*\r?\n|\r?\n))/
   },
   'meta_testml_statement' => {
-    '+re' => qr/(?-xism:\G%TestML:[\ \t]+(([0-9]\.[0-9]+))(?:[\ \t]+#.*\r?\n|\r?\n))/
+    '+re' => qr/(?-xism:\G%TestML:[\ \t]+(([0-9]\.[0-9]+))(?:[\ \t]+\#.*\r?\n|\r?\n))/
   },
   'phrase_point' => {
     '+all' => [
@@ -288,7 +278,7 @@ our $grammar = +{
         '+re' => qr/(?-xism:\G\r?\n)/
       },
       {
-        '+re' => qr/(?-xism:\G(?:#.*\r?\n|[\ \t]*\r?\n)*)/
+        '+re' => qr/(?-xism:\G(?:\#.*\r?\n|[\ \t]*\r?\n)*)/
       }
     ]
   },
@@ -305,7 +295,7 @@ our $grammar = +{
     '+re' => qr/(?-xism:\G([a-z]\w*))/
   },
   'point_phrase' => {
-    '+re' => qr/(?-xism:\G(([^\ \t\n#](?:[^\n#]*[^\ \t\n#])?)))/
+    '+re' => qr/(?-xism:\G(([^\ \t\n\#](?:[^\n\#]*[^\ \t\n\#])?)))/
   },
   'quoted_string' => {
     '+any' => [
@@ -380,10 +370,10 @@ our $grammar = +{
       {
         '+any' => [
           {
-            '+rule' => 'SEMI'
+            '+re' => qr/(?-xism:\G;)/
           },
           {
-            '+rule' => 'SEMICOLON_ERROR'
+            '+error' => 'You seem to be missing a semicolon'
           }
         ]
       }
@@ -399,14 +389,14 @@ our $grammar = +{
   'transform_argument_list' => {
     '+all' => [
       {
-        '+re' => qr/(?-xism:\G\((?:[\ \t]|\r?\n|#.*\r?\n)*)/
+        '+re' => qr/(?-xism:\G\((?:[\ \t]|\r?\n|\#.*\r?\n)*)/
       },
       {
         '+rule' => 'transform_arguments',
         '<' => '?'
       },
       {
-        '+re' => qr/(?-xism:\G(?:[\ \t]|\r?\n|#.*\r?\n)*\))/
+        '+re' => qr/(?-xism:\G(?:[\ \t]|\r?\n|\#.*\r?\n)*\))/
       }
     ]
   },
@@ -418,7 +408,7 @@ our $grammar = +{
       {
         '+all' => [
           {
-            '+re' => qr/(?-xism:\G(?:[\ \t]|\r?\n|#.*\r?\n)*,(?:[\ \t]|\r?\n|#.*\r?\n)*)/
+            '+re' => qr/(?-xism:\G(?:[\ \t]|\r?\n|\#.*\r?\n)*,(?:[\ \t]|\r?\n|\#.*\r?\n)*)/
           },
           {
             '+rule' => 'transform_argument'
@@ -450,13 +440,13 @@ our $grammar = +{
     ]
   },
   'unquoted_string' => {
-    '+re' => qr/(?-xism:\G([^\ \t\n#](?:[^\n#]*[^\ \t\n#])?))/
+    '+re' => qr/(?-xism:\G([^\ \t\n\#](?:[^\n\#]*[^\ \t\n\#])?))/
   },
   'user_transform' => {
     '+re' => qr/(?-xism:\G([a-z]\w*))/
   },
   'ws' => {
-    '+re' => qr/(?-xism:\G(?:[\ \t]|\r?\n|#.*\r?\n))/
+    '+re' => qr/(?-xism:\G(?:[\ \t]|\r?\n|\#.*\r?\n))/
   },
   'xml_data_section' => {
     '+re' => qr/(?-xism:\G(<.+))/
@@ -465,9 +455,6 @@ our $grammar = +{
     '+re' => qr/(?-xism:\G(---[\ \t]*\r?\n.+))/
   }
 };
-
-sub grammar {
-    return $grammar;
 }
 
 1;
